<?php

use Starfish\Freemius as SRM_FREEMIUS;
use Starfish\Funnels as SRM_FUNNELS;
use Starfish\Premium\Collections as SRM_COLLECTIONS;
use Starfish\Settings as SRM_SETTINGS;
use Starfish\Utils as SRM_UTILS;

/**
 * Main scripts
 */
function srm_main_scripts() {
	global $post, $pagenow;
	// Global site scripts.
	wp_enqueue_style('srm_main', SRM_PLUGIN_URL . '/css/starfish-main.css', false, SRM_VERSION, 'all');
	wp_enqueue_script('jquery');

	$funnel_id = SRM_UTILS::is_funnel_present($post);
	$collection_id = SRM_UTILS::is_collection_present($post);
	if(SRM_UTILS::is_starfish_page( $post, $pagenow, $_GET ) || ( (!empty($post) && ($funnel_id !== false || $collection_id !== false ) ) ) ) {
		wp_enqueue_style('jquery-ui', 'https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.css', false, '1.12.1', 'all');
		wp_enqueue_style('srm_fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css', false, '5.15.2', 'all');
		wp_enqueue_script('jquery-ui', 'https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js', false, '1.12.1', false);
		wp_enqueue_script('srm_main', SRM_PLUGIN_URL . '/js/starfish-main.js', false, SRM_VERSION, false);
		// Check if shortcodes are being used and enqueue styles/scripts accordingly.
		if ($funnel_id !== false) {
			SRM_FUNNELS::srm_enqueue_public_funnel_scripts($funnel_id);
			SRM_FUNNELS::srm_localize_funnel_scripts($funnel_id);
		}
		if ($collection_id !== false) {
			SRM_COLLECTIONS::srm_enqueue_collection_scripts($collection_id);
		}
	}
}

add_action( 'wp_enqueue_scripts', 'srm_main_scripts' );
add_action( 'admin_enqueue_scripts', 'srm_main_scripts' );

/**
 * Admin scripts
 */
function srm_admin_scripts() {
	global $pagenow, $post;
	$current_user = wp_get_current_user();

	$fa_data = array(
		'has_license' => SRM_FREEMIUS::starfish_fs()->has_active_valid_license(),
	);

	$funnel_default_settings = SRM_SETTINGS::srm_get_options( 'defaults' );
	foreach ( $funnel_default_settings as $key => $option ) {
		$funnel_default_settings[ $key ]['current'] = get_option( $key, $option['default'] );
	}

	// Localized Variables.
	$admin_settings_variables = array(
		'defaults'         => $funnel_default_settings,
		'ajax_url'         => admin_url( 'admin-ajax.php' ),
		'collection_nonce' => wp_create_nonce( 'srm_collection' ),
		'settings_nonce'   => wp_create_nonce( 'srm_settings' ),
		'help_data'        => array(
			'user_display_name' => esc_html( $current_user->display_name ),
			'user_email'        => esc_html( $current_user->user_email ),
		),
	);

	$admin_funnel_variables = array(
		'icons' => SRM_FUNNELS::srm_get_icons(),
	);

	// Global WordPress: scripts and styles.
	wp_enqueue_style( 'srm_highlight', 'https://cdnjs.cloudflare.com/ajax/libs/highlight.js/10.6.0/styles/agate.min.css', false, '10.6.0', 'all' );
	wp_enqueue_style( 'srm_admin_main', SRM_PLUGIN_URL . '/css/starfish-admin-main.css', false, SRM_VERSION, 'all' );
	wp_enqueue_script( 'srm_highlight', 'https://cdnjs.cloudflare.com/ajax/libs/highlight.js/10.6.0/highlight.min.js', false, '10.6.0', false );
	wp_enqueue_script( 'srm_admin_main', SRM_PLUGIN_URL . '/js/starfish-admin-main.js', false, SRM_VERSION, false );

	// Global Starfish: scripts and styles.
	if ( SRM_UTILS::is_starfish_page( $post, $pagenow, $_GET ) ) {
		wp_enqueue_style( 'srm_settings', SRM_PLUGIN_URL . '/css/starfish-settings.css', false, SRM_VERSION, 'all' );
		wp_enqueue_style( 'srm_bootstrap', 'https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css', false, '4.4.1', 'all' );
		wp_enqueue_style( 'srm_toggle', 'https://gitcdn.github.io/bootstrap-toggle/2.2.2/css/bootstrap-toggle.min.css', false, '2.2.2', 'all' );
		wp_enqueue_style( 'srm_confirm', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.2/jquery-confirm.min.css', false, '3.3.2', 'all' );
		wp_enqueue_script( 'srm_clipboard', 'https://cdnjs.cloudflare.com/ajax/libs/clipboard.js/2.0.10/clipboard.min.js', false, '2.0.10', false );  // Cannot be in footer.
		wp_enqueue_script( 'srm_popper', 'https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js', false, '1.14.7', true );
		wp_enqueue_script( 'srm_main', SRM_PLUGIN_URL . '/js/starfish-main.js', false, SRM_VERSION, true );
		wp_enqueue_script( 'srm_freemius_account', SRM_PLUGIN_URL . '/js/starfish-admin-freemius-account.js', false, SRM_VERSION, true );
		wp_enqueue_script( 'srm_bootstrap', 'https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/js/bootstrap.min.js', false, '4.4.1', true );
		wp_enqueue_script( 'srm_confirm', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.2/jquery-confirm.min.js', false, '3.3.2', true );
		wp_enqueue_script( 'srm_toggle', 'https://gitcdn.github.io/bootstrap-toggle/2.2.2/js/bootstrap-toggle.min.js', false, '2.2.2', true );
		// Script Localization
		wp_localize_script( 'srm_freemius_account', 'fa_data', $fa_data );
	}

	// Funnel: Admin page.
	if ( SRM_UTILS::is_starfish_funnel( $post, $pagenow ) ) {
		$post_id                               = $post->ID;
		$admin_settings_variables['funnel_id'] = $post_id;
		wp_enqueue_style( 'srm_funnels_admin', SRM_PLUGIN_URL . '/css/starfish-funnel-admin.css', false, SRM_VERSION, 'all' );
		wp_enqueue_script( 'srm_funnel_admin', SRM_PLUGIN_URL . '/js/starfish-admin-funnel.js', false, SRM_VERSION, true );
		wp_enqueue_script( 'srm_funnel_admin_multi_destinations', SRM_PLUGIN_URL . '/js/starfish-admin-funnel-multidestinations.js', false, SRM_VERSION, true );
		// Script Localization: Admin Funnel.
		wp_localize_script( 'srm_funnel_admin_multi_destinations', 'funnel_vars', $admin_funnel_variables );
		wp_localize_script( 'srm_funnel_admin', 'settings', $admin_settings_variables );
	}

	// Feedback: Admin page.
	if ( SRM_UTILS::is_starfish_feedback( $post, $pagenow ) ) {
		$admin_feedback_variables['funnel_id']      = ( isset( $_GET['funnel_id'] ) ) ? esc_html( $_GET['funnel_id'] ) : null;
		$admin_feedback_variables['month']          = ( isset( $_GET['m'] ) ) ? $_GET['m'] : null;
		$admin_feedback_variables['feedback_nonce'] = wp_create_nonce( 'srm-export-feedback', 'export_feedback_nonce' );
		wp_enqueue_script( 'srm_feedback_admin', SRM_PLUGIN_URL . '/js/starfish-admin-feedback.js', false, SRM_VERSION, false );
		// Script Localization: Admin Feedback.
		wp_localize_script( 'srm_feedback_admin', 'feedback_vars', $admin_feedback_variables );
	}

	// Starfish Settings.
	if ( SRM_UTILS::is_starfish_settings( $post, $pagenow, $_GET ) ) {
		wp_enqueue_script( 'srm_admin_settings', SRM_PLUGIN_URL . '/js/starfish-admin-settings.js', false, SRM_VERSION, false );
		// Script Localization: Admin Settings.
		wp_localize_script( 'srm_admin_settings', 'settings_vars', $admin_settings_variables );
	}
}

add_action( 'admin_enqueue_scripts', 'srm_admin_scripts' );
