<?php

namespace Starfish;

use  Starfish\Freemius as SRM_FREEMIUS ;
use  Starfish\Cron as SRM_CRON ;
use  Starfish\Logging as SRM_LOGGING ;
use function  define ;
use function  str_replace ;
use function  wp_get_upload_dir ;
use const  SRM_PLUGIN_PATH ;
class StarfishReviews
{
    /**
     * Initiate the Starfish Activation & Deactivation Logic.
     */
    public static function init()
    {
        self::plugin_constants();
        // Load Core Starfish classes
        include SRM_PLUGIN_PATH . 'src/Freemius.class.php';
        include SRM_PLUGIN_PATH . 'src/Cron.class.php';
        include SRM_PLUGIN_PATH . 'src/Settings.class.php';
        // Autoload all other Starfish classes
        spl_autoload_register( function ( $class ) {
            if ( strpos( $class, SRM_NAMESPACE ) !== false ) {
                include SRM_PLUGIN_PATH . str_replace( SRM_NAMESPACE, 'src/', str_replace( '\\', '/', $class ) ) . '.class.php';
            }
        } );
        add_action( 'init', array( __CLASS__, 'load_plugin_languages' ) );
        SRM_CRON::init();
        require_once SRM_PLUGIN_PATH . 'init/starfish-activation.php';
        require_once SRM_PLUGIN_PATH . 'init/starfish-deactivation.php';
        register_activation_hook( SRM_MAIN_FILE, 'srm_plugin_install' );
        register_deactivation_hook( SRM_MAIN_FILE, 'srm_plugin_uninstall' );
        self::required_actions();
        self::required_filters();
        self::basic_includes();
        // Premium Plan
        define( 'SRM_FREEMIUS_PLAN_TITLE', SRM_FREEMIUS::starfish_fs()->get_plan_title() );
        define( 'SRM_PLAN_TITLE', ( empty(SRM_FREEMIUS_PLAN_TITLE) || SRM_FREEMIUS_PLAN_TITLE == 'PLAN_TITLE' ? _x( 'FREE', 'The Free Subscription Plan', 'starfish' ) : SRM_FREEMIUS_PLAN_TITLE ) );
    }
    
    /**
     * Define Plugin Constants
     */
    public static function plugin_constants()
    {
        $uploads = wp_get_upload_dir();
        define( 'SRM_BUSINESS_PLAN', 'business_v2' );
        define( 'SRM_ENTREPRENEUR_PLAN', 'entrepreneur' );
        define( 'SRM_AGENCY_PLAN', 'agency' );
        define( 'SRM_MARKETER_PLAN_LEGACY', 'marketer' );
        define( 'SRM_WEBMASTER_PLAN_LEGACY', 'webmaster' );
        define( 'SRM_BUSINESS_PLAN_LEGACY', 'business' );
        define( 'SRM_PLUGIN_ACTIVE', true );
        define( 'SRM_SITE_URL', get_site_url() );
        define( 'SRM_PLANS_URL', 'https://starfish.reviews/plans-pricing' );
        define( 'SRM_PRICING_ADMIN_URL', admin_url( '/admin.php?page=starfish-settings-pricing&billing_cycle=annual&trial=true' ) );
        define( 'SRM_NAMESPACE', 'Starfish' );
        define( 'SRM_UPLOADS_DIR', $uploads['basedir'] . '/starfish/' );
        define( 'SRM_UPLOADS_URL', $uploads['baseurl'] . '/starfish/' );
        define( 'SRM_LOG_FILE', SRM_PLUGIN_PATH . 'srm_logs.txt' );
        define( 'SRM_GO_PREMIUM_LINK', '<a class="premium-only-link" href="' . SRM_PLANS_URL . '" title="Upgrade Starfish Plan">' . __( 'Go Premium!', 'starfish' ) . '</a>' );
        // Plugin Option Groups!
        define( 'SRM_OPTION_GROUP_GENERAL', 'srm_general_options' );
        define( 'SRM_OPTION_GROUP_EMAIL', 'srm_email_options' );
        define( 'SRM_OPTION_GROUP_DEFAULTS', 'srm_defaults_options' );
        define( 'SRM_OPTION_GROUP_TOOLBOX', 'srm_toolbox_options' );
        define( 'SRM_OPTION_GROUP_REVIEWS', 'srm_reviews_options' );
        define( 'SRM_OPTION_GROUP_SUPPORT_GENERAL', 'srm_support_options' );
        define( 'SRM_OPTION_GROUP_SUPPORT_CONSOLE', 'srm_support_console_options' );
        define( 'SRM_OPTION_GROUP_SUPPORT_INFO', 'srm_support_info_options' );
        // Plugin Options!
        define( 'SRM_OPTION_LOGGING', 'srm_logging' );
        define( 'SRM_OPTION_SUPPORT_ALERTS', 'srm_support_alerts' );
        define( 'SRM_OPTION_INSTALL_DATE', 'srm_install_date' );
        define( 'SRM_OPTION_ALL_FUNNELS', 'srm_all_funnels' );
        define( 'SRM_OPTION_FUNNEL_ARCHIVES', 'srm_funnel_archives' );
        define( 'SRM_OPTION_FUNNEL_SLUG', 'srm_feedback_slug' );
        define( 'SRM_OPTION_HIDE_BRANDING', 'srm_branding' );
        define( 'SRM_OPTION_REPLY_TO_EMAIL', 'srm_replay_to_email' );
        define( 'SRM_OPTION_CLEAN_ON_DEACTIVATE', 'srm_clean_on_deactive' );
        define( 'SRM_OPTION_AFFILIATE_URL', 'srm_affiliate_url' );
        define( 'SRM_OPTION_EMAIL_FROM_NAME', 'srm_email_from_name' );
        define( 'SRM_OPTION_EMAIL_FROM_EMAIL', 'srm_email_from_email' );
        define( 'SRM_OPTION_EMAIL_SUBJECT', 'srm_email_subject' );
        define( 'SRM_OPTION_EMAIL_TEMPLATE', 'srm_email_template' );
        define( 'SRM_OPTION_DEFAULT_FEEDBACK_EMAIL', 'srm_default_feedback_email' );
        define( 'SRM_OPTION_MSG_NO_THANK_YOU', 'srm_msg_no_thank_you' );
        define( 'SRM_OPTION_DEFAULT_NO_FEEDBACK_PROMPT', 'srm_default_no_review_prompt' );
        define( 'SRM_OPTION_DEFAULT_REVIEW_PROMPT', 'srm_default_review_prompt' );
        define( 'SRM_OPTION_DEFAULT_SUBMIT_BUTTON_NO', 'srm_default_submit_button_no' );
        define( 'SRM_OPTION_DEFAULT_SUBMIT_BUTTON', 'srm_default_submit_button' );
        define( 'SRM_OPTION_DEFAULT_YN_QUESTION', 'srm_default_yn_question' );
        define( 'SRM_OPTION_YES_REDIRECT_SECONDS', 'srm_yes_redirect_seconds' );
        define( 'SRM_OPTION_DEFAULT_PUBLIC_REVIEW_TEXT', 'srm_default_public_review_text' );
        define( 'SRM_OPTION_DEFAULT_SKIP_FEEDBACK_TEXT', 'srm_default_skip_feedback_text' );
        define( 'SRM_OPTION_REVIEW_SCRAPE_CRON', 'srm_review_scrape_cron' );
        define( 'SRM_OPTION_REVIEW_SCRAPE_REFRESH_TIME', 'srm_review_scrape_refresh_time' );
        // Funnel Meta Data.
        define( 'SRM_META_REVIEWER_NAME', '_srm_reviewer_name' );
        define( 'SRM_META_REVIEWER_EMAIL', '_srm_reviewer_email' );
        define( 'SRM_META_REVIEWER_PHONE', '_srm_reviewer_phone' );
        define( 'SRM_META_REVIEWER_FEEDBACK', '_srm_feedback' );
        define( 'SRM_META_FUNNEL_ID', '_srm_funnel_id' );
        define( 'SRM_META_DESTI_NAME', '_srm_desti_name' );
        define( 'SRM_META_DESTI_URL', '_srm_destination_url' );
        define( 'SRM_META_DESTI_TYPE', '_srm_desti_type' );
        define( 'SRM_META_FEEDBACK_ID', '_srm_feedback' );
        define( 'SRM_META_EMAIL_FEEDBACK', '_srm_email_feedback' );
        define( 'SRM_META_TRACKING_ID', '_srm_tracking_id' );
        // Plugin Migrations!
        define( 'SRM_MIGRATIONS', 'srm_migrations' );
        // Plugin Dialogues.
        define( 'SRM_DIALOGUE_HELP_FUNNEL', SRM_PLUGIN_PATH . 'inc/dialogues/starfish-help-funnel.dialogue.php' );
        define( 'SRM_DIALOGUE_HELP_SETTINGS', SRM_PLUGIN_PATH . 'inc/dialogues/starfish-help-settings.dialogue.php' );
        define( 'SRM_DIALOGUE_REVIEW_DETAILS', SRM_PLUGIN_PATH . 'inc/dialogues/starfish-review-details.dialogue__premium_only.php' );
        define( 'SRM_DIALOGUE_REVIEWS_PROFILES', SRM_PLUGIN_PATH . 'inc/dialogues/starfish-reviews-profiles.dialogue__premium_only.php' );
        // User Meta Keys.
        define( 'SRM_ADMIN_NOTICE_HOW_STARFISH_WORKS_ALERT', 'srm_how_starfish_works_alert' );
        define( 'SRM_ADMIN_NOTICE_FEEDBACK_NEW_ALERT', 'srm_feedback_new_alert' );
        define( 'SRM_ADMIN_NOTICE_FUNNELS_COUNT_ALERT', 'srm_funnels_count_alert' );
        define( 'SRM_ADMIN_NOTICE_COLLECTIONS_COUNT_ALERT', 'srm_collections_count_alert' );
        define( 'SRM_ADMIN_NOTICE_PROFILES_COUNT_ALERT', 'srm_profiles_count_alert' );
        define( 'SRM_ADMIN_NOTICE_FUNNELS_COUNT_VIOLATIONS_ALERT', 'srm_funnels_count_violations_alert' );
        define( 'SRM_ADMIN_NOTICE_COLLECTIONS_COUNT_VIOLATIONS_ALERT', 'srm_collections_count_violations_alert' );
        define( 'SRM_ADMIN_NOTICE_PROFILES_COUNT_VIOLATIONS_ALERT', 'srm_profiles_count_violations_alert' );
        // Transients.
        define( 'SRM_TRAN_CRON_LAST_PROFILE_SCRAPE_DATE', 'srm_cron_last_profile_scrape_run' );
        define( 'SRM_TRAN_PLAN_LIMITS', 'srm_plan_limits' );
    }
    
    /**
     * Included Actions
     */
    public static function required_actions()
    {
        // Initial.
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-feedback-process.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-admin-notices.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-funnels.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-feedback.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-pluginloaded.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-enqueue-scripts.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-templates.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/options/starfish-admin-options.action.php';
        // Admin Menus.
        require_once SRM_PLUGIN_PATH . 'init/actions/menu/starfish-admin-menu-parent.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/menu/starfish-admin-menu-settings.action.php';
        // API.
        require_once SRM_PLUGIN_PATH . 'init/actions/api/starfish-api-meta.action.php';
        // AJAX Callbacks.
        require_once SRM_PLUGIN_PATH . 'init/actions/ajax/starfish-ajax-callbacks.action.php';
        // General.
        require_once SRM_PLUGIN_PATH . 'init/actions/menu/starfish-admin-menu-bar.action.php';
        require_once SRM_PLUGIN_PATH . 'init/actions/starfish-footer.action.php';
    }
    
    /**
     * Included Filters
     */
    public static function required_filters()
    {
        require_once SRM_PLUGIN_PATH . 'init/filters/starfish-action-links.filter.php';
        require_once SRM_PLUGIN_PATH . 'init/filters/starfish-feedback-admin.filter.php';
        require_once SRM_PLUGIN_PATH . 'init/filters/starfish-api.filter.php';
        require_once SRM_PLUGIN_PATH . 'init/filters/starfish-admin-funnel-columns.filter.php';
    }
    
    /**
     * Basic Includes
     */
    public static function basic_includes()
    {
    }
    
    /**
     * Initialize localization
     */
    public static function load_plugin_languages()
    {
        // load plugin languages.
        load_plugin_textdomain( 'starfish', false, SRM_PLUGIN_PATH . '/languages/' );
    }

}