<?php

namespace Starfish;

use DOMDocument;

/**
 * General Starfish Utilities
 *
 * @category   Reviews
 * @package    WordPress
 * @subpackage Starfish
 *
 * @author  silvercolt45 <webmaster@silvercolt.com>
 * @license https://www.gnu.org/licenses/gpl-3.0.txt GNU/GPLv3
 * @version Release: 1.0
 * @since   Release: 2.4.0
 */
class Utils {

	const EDIT_ROOT = 'edit.php';
	const POST_ROOT = 'post.php';
	const POST_NEW  = 'post-new.php';

	/**
	 * Check if current page is a Starfish page
	 *
	 * @return bool
	 */
	public static function is_starfish_page( $post, $pagenow, $get ) {
		if ( ( isset( $post ) && ( 'funnel' == $post->post_type ) && ( ( self::POST_ROOT === $pagenow ) || ( self::POST_NEW === $pagenow ) || ( self::EDIT_ROOT === $pagenow ) ) )
			|| ( isset( $post ) && ( 'collection' == $post->post_type ) && ( ( self::POST_ROOT === $pagenow ) || ( self::POST_NEW === $pagenow ) || ( self::EDIT_ROOT === $pagenow ) ) )
			|| ( isset( $post ) && ( 'funnel' == $post->post_type || 'collection' == $post->post_type ) )
			|| ( isset( $get['page'] ) && 'starfish-settings' === $get['page'] )
			|| ( isset( $get['post_type'] ) && 'starfish_feedback' === $get['post_type'] )
			|| ( isset( $get['page'] ) && ( 'starfish-reviews-profiles' === $get['page'] || 'starfish-reviews' === $get['page'] ) )
			|| ( isset( $get['post_type'] ) && 'collection' === $get['post_type'] )
			|| ( isset( $get['action'] ) && 'edit' === $get['action'] && self::POST_ROOT === $pagenow && isset( $post )
			&& ( esc_html( get_option( SRM_OPTION_FUNNEL_SLUG ) ) == get_post_type( $get['post'] ) || 'collection' == get_post_type( $get['post'] ) || 'starfish_feedback' == get_post_type( $get['post'] ) ) )
		) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Check if current page is a Starfish Funnel
	 *
	 * @param $post
	 * @param $pagenow
	 *
	 * @return bool
	 */
	public static function is_starfish_funnel( $post, $pagenow ) {
		if ( isset( $post ) && ( 'funnel' == $post->post_type ) && ( ( self::POST_ROOT === $pagenow ) || ( self::POST_NEW === $pagenow ) ) ) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Check if current page is a Starfish Feedback
	 *
	 * @param $post
	 * @param $pagenow
	 *
	 * @return bool
	 */
	public static function is_starfish_feedback( $post, $pagenow ) {
		if ( isset( $post ) && ( 'starfish_feedback' === $post->post_type ) && ( ( self::EDIT_ROOT === $pagenow ) ) ) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Check if current page is a Starfish Collection
	 *
	 * @param $post
	 * @param $pagenow
	 *
	 * @return bool
	 */
	public static function is_starfish_collection( $post, $pagenow, $get ) {
		if ( ( isset( $post ) && ( 'collection' === $post->post_type ) && ( ( 'post.php' === $pagenow ) || ( self::POST_NEW === $pagenow ) ) )
			|| ( ( self::EDIT_ROOT === $pagenow ) && ( isset( $get['post_type'] ) && 'collection' === $get['post_type'] ) )
			|| ( isset( $get['post_type'] ) && 'collection' === $get['post_type'] )
		) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Check if current page is a Starfish Reviews Profile
	 *
	 * @param $post
	 * @param $pagenow
	 *
	 * @return bool
	 */
	public static function is_starfish_reviews_profile( $post, $pagenow, $get ) {
		if ( isset( $get['page'] ) && ( 'starfish-reviews-profiles' === $get['page'] || 'starfish-reviews' === $get['page'] ) ) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Check if current page is a Starfish Settings
	 *
	 * @param $post
	 * @param $pagenow
	 *
	 * @return bool
	 */
	public static function is_starfish_settings( $post, $pagenow, $get ) {
		if ( ( isset( $get['page'] ) && 'starfish-settings' === $get['page'] ) ) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Date Compare for use in usort() function
	 *
	 * @param $a
	 * @param $b
	 *
	 * @return false|int
	 */
	public static function date_compare( $a, $b ) {
		 $t1 = strtotime( $a['created'] );
		$t2  = strtotime( $b['created'] );
		return $t1 - $t2;
	}

	/**
	 * @param  $shortcode_tag
	 * @param  $post
	 * @return array|false
	 */
	public static function get_shortcode_attributes( $shortcode_tag, $post ) {
		if ( has_shortcode( $post->post_content, $shortcode_tag ) ) {
			$output = array();
			// get shortcode regex pattern WordPress function
			$pattern = get_shortcode_regex( array( $shortcode_tag ) );
			if ( preg_match_all( '/' . $pattern . '/s', $post->post_content, $matches ) ) {
				$out = array();
				if ( isset( $matches[2] ) ) {
					foreach ( (array) $matches[2] as $key => $value ) {
						if ( $shortcode_tag === $value ) {
							$out[] = shortcode_parse_atts( $matches[3][ $key ] );
						}
					}
				}
				return $out;
			} else {
				return false;
			}
		} else {
			return false;
		}
	}

	/**
	 * Check if page has funnel present.
	 *
	 * @return integer|bool Funnel ID if found otherwise false
	 */
	public static function is_funnel_present( $post ) {

		if ( ! empty( $post ) ) {
			$query = get_post( $post->ID );
			// Check normal shortcode usage.
			$shortcode_attrs = self::get_shortcode_attributes( 'starfish', $post );
			if ( ! empty( $shortcode_attrs ) ) {
				foreach ( $shortcode_attrs as $shortcode ) {
					if ( isset( $shortcode['funnel'] ) ) {
						return $shortcode['funnel'];
					}
				}
			// Check for any signs of funnel HTML.
			} elseif ( ! empty( $query->post_content ) ) {
				$page_html = apply_filters( 'the_content', $query->post_content );
				$domdoc    = new DOMDocument();
				libxml_use_internal_errors(true);
				$domdoc->loadHTML( $page_html );
				if ( strpos( $page_html, 'srm-funnel' ) !== false ) {
					$divs = $domdoc->getElementsByTagName( 'div' );
					foreach ( $divs as $div ) {
						if ( ! empty( $div->getAttribute( 'data-funnel_id' ) ) ) {
							return $div->getAttribute( 'data-funnel_id' );
						}
					}
				}
				libxml_clear_errors();
			}
		}
		return false;
	}

	/**
	 * Check if page has Collection present.
	 *
	 * @return integer|bool Collection ID if found otherwise false
	 */
	public static function is_collection_present( $post ) {

		if ( ! empty( $post ) ) {
			$query = get_post( $post->ID );
			// Check normal shortcode usage.
			$shortcode_attrs = self::get_shortcode_attributes( 'starfish', $post );
			if ( ! empty( $shortcode_attrs ) ) {
				foreach ( $shortcode_attrs as $shortcode ) {
					if ( isset( $shortcode['collection'] ) ) {
						return $shortcode['collection'];
					}
				}
				// Check for any signs of funnel HTML.
			} elseif ( ! empty( $query->post_content ) ) {
				$page_html = apply_filters( 'the_content', $query->post_content );
				$domdoc    = new DOMDocument();
				libxml_use_internal_errors(true);
				$domdoc->loadHTML( $page_html );
				if ( strpos( $page_html, 'srm-collection' ) !== false ) {
					$divs = $domdoc->getElementsByTagName( 'div' );
					foreach ( $divs as $div ) {
						if ( ! empty( $div->getAttribute( 'data-collection_id' ) ) ) {
							return $div->getAttribute( 'data-collection_id' );
						}
					}
				}
				libxml_clear_errors();
			}
		}
		return false;
	}

	/**
	 * Enqueue all base scripts for the plugin
	 *
	 * @return void
	 */
	public static function enqueue_base_scripts() {

		wp_enqueue_style('jquery-ui', 'https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.css', null, '1.12.1', 'all');
		wp_enqueue_style('srm_fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css', null, '5.15.2', 'all');
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui', 'https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js', null, '1.12.1', false);
		wp_enqueue_script('srm_main', SRM_PLUGIN_URL . '/js/starfish-main.js', null, SRM_VERSION, false);

	}
}
